==> ffe-system-message-react-8.0.18.tgz: package/es/SystemMessage.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["animationLengthMs", "children", "className", "icon", "locale", "modifier", "onColoredBg"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
import React, { Component } from 'react';
import { func, string, number, node, oneOf, bool } from 'prop-types';
import classNames from 'classnames';
import { Icon } from '@sb1/ffe-icons-react';
import texts from './texts';
var SystemMessage = /*#__PURE__*/function (_Component) {
  _inherits(SystemMessage, _Component);
  function SystemMessage() {
    var _this;
    _classCallCheck(this, SystemMessage);
    _this = _callSuper(this, SystemMessage);
    _this.close = _this.close.bind(_assertThisInitialized(_this));
    _this.state = {
      closed: false
    };
    return _this;
  }
  _createClass(SystemMessage, [{
    key: "close",
    value: function close(event) {
      var _this2 = this;
      var _this$props = this.props,
        animationLengthMs = _this$props.animationLengthMs,
        onClose = _this$props.onClose;
      var self = this._self;
      self.style.height = "".concat(self.offsetHeight, "px");
      setTimeout(function () {
        self.style.height = 0;
      }, 0);
      setTimeout(function () {
        _this2.setState({
          closed: true
        }, function () {
          onClose(event);
        });
      }, animationLengthMs);
      return false;
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;
      var _this$props2 = this.props,
        animationLengthMs = _this$props2.animationLengthMs,
        children = _this$props2.children,
        className = _this$props2.className,
        icon = _this$props2.icon,
        locale = _this$props2.locale,
        modifier = _this$props2.modifier,
        onColoredBg = _this$props2.onColoredBg,
        rest = _objectWithoutProperties(_this$props2, _excluded);
      if (this.state.closed) {
        return null;
      }
      return /*#__PURE__*/React.createElement("div", _extends({
        className: classNames('ffe-system-message-wrapper', "ffe-system-message-wrapper--".concat(modifier), {
          'ffe-system-message-wrapper--coloredbg': onColoredBg
        }, className),
        role: "group",
        ref: function ref(_self) {
          _this3._self = _self;
        },
        style: {
          transition: "height ".concat(animationLengthMs / 1000, "s")
        }
      }, rest), /*#__PURE__*/React.createElement("div", {
        className: "ffe-system-message"
      }, /*#__PURE__*/React.createElement("span", {
        className: "ffe-system-message__icon"
      }, icon && /*#__PURE__*/React.cloneElement(icon, _objectSpread({}, icon.props))), /*#__PURE__*/React.createElement("p", {
        className: "ffe-system-message__content"
      }, children), /*#__PURE__*/React.createElement("button", {
        "aria-label": texts[locale].close,
        className: "ffe-system-message__close",
        onClick: this.close,
        type: "button"
      }, /*#__PURE__*/React.createElement(Icon, {
        fileUrl: "data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMjAiIHZpZXdCb3g9IjAgLTk2MCA5NjAgOTYwIiB3aWR0aD0iMjAiPjxwYXRoIGQ9Ik00ODAtNDQyLjg0NyAzMDkuMDc2LTI3MS45MjRxLTguMzA3IDguMzA4LTE3Ljg4NCA4LTkuNTc2LS4zMDctMTguMjY4LTktOC42OTMtOC42OTItOC42OTMtMTguNTc2dDguNjkzLTE4LjU3Nkw0NDIuODQ3LTQ4MCAyNzEuOTI0LTY1MC45MjRxLTguMzA4LTguMzA3LTgtMTguMzg0LjMwNy0xMC4wNzYgOS0xOC43NjggOC42OTItOC42OTMgMTguNTc2LTguNjkzdDE4LjU3NiA4LjY5M0w0ODAtNTE3LjE1M2wxNzAuOTI0LTE3MC45MjNxOC4zMDctOC4zMDggMTguMzg0LTguNSAxMC4wNzYtLjE5MyAxOC43NjggOC41IDguNjkzIDguNjkyIDguNjkzIDE4LjU3NnQtOC42OTMgMTguNTc2TDUxNy4xNTMtNDgwbDE3MC45MjMgMTcwLjkyNHE4LjMwOCA4LjMwNyA4LjUgMTcuODg0LjE5MyA5LjU3Ni04LjUgMTguMjY4LTguNjkyIDguNjkzLTE4LjU3NiA4LjY5M3QtMTguNTc2LTguNjkzTDQ4MC00NDIuODQ3WiIvPjwvc3ZnPg==",
        size: "sm"
      }))));
    }
  }]);
  return SystemMessage;
}(Component);
SystemMessage.defaultProps = {
  animationLengthMs: 300,
  locale: 'nb',
  onClose: function onClose(f) {
    return f;
  }
};
SystemMessage.propTypes = {
  animationLengthMs: number,
  /** The content of the system message */
  children: node.isRequired,
  /** Additional classes added to the surrounding div */
  className: string,
  /** Override the default icon - use with caution! */
  icon: node.isRequired,
  /** 'nb', 'nn', or 'en' */
  locale: oneOf(['en', 'nb', 'nn']),
  /**
   * The type of system message. Used internally only-
   * @ignore
   **/
  modifier: oneOf(['error', 'info', 'success', 'news']),
  /** Callback for when the system message has been closed (after animation ends) */
  onClose: func,
  /* Adds alternative styling for better contrast on certain backgrounds */
  onColoredBg: bool
};
export default SystemMessage;

==> ffe-system-message-react-8.0.23.tgz: package/es/SystemMessage.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["animationLengthMs", "children", "className", "icon", "locale", "modifier", "onColoredBg"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _callSuper(t, o, e) { return o = _getPrototypeOf(o), _possibleConstructorReturn(t, _isNativeReflectConstruct() ? Reflect.construct(o, e || [], _getPrototypeOf(t).constructor) : o.apply(t, e)); }
function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }
function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }
function _isNativeReflectConstruct() { try { var t = !Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); } catch (t) {} return (_isNativeReflectConstruct = function _isNativeReflectConstruct() { return !!t; })(); }
function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }
function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
import React, { Component } from 'react';
import { func, string, number, node, oneOf, bool } from 'prop-types';
import classNames from 'classnames';
import { Icon } from '@sb1/ffe-icons-react';
import texts from './texts';
var SystemMessage = /*#__PURE__*/function (_Component) {
  function SystemMessage() {
    var _this;
    _classCallCheck(this, SystemMessage);
    _this = _callSuper(this, SystemMessage);
    _this.close = _this.close.bind(_this);
    _this.state = {
      closed: false
    };
    return _this;
  }
  _inherits(SystemMessage, _Component);
  return _createClass(SystemMessage, [{
    key: "close",
    value: function close(event) {
      var _this2 = this;
      var _this$props = this.props,
        animationLengthMs = _this$props.animationLengthMs,
        onClose = _this$props.onClose;
      var self = this._self;
      self.style.height = "".concat(self.offsetHeight, "px");
      setTimeout(function () {
        self.style.height = 0;
      }, 0);
      setTimeout(function () {
        _this2.setState({
          closed: true
        }, function () {
          onClose(event);
        });
      }, animationLengthMs);
      return false;
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;
      var _this$props2 = this.props,
        animationLengthMs = _this$props2.animationLengthMs,
        children = _this$props2.children,
        className = _this$props2.className,
        icon = _this$props2.icon,
        locale = _this$props2.locale,
        modifier = _this$props2.modifier,
        onColoredBg = _this$props2.onColoredBg,
        rest = _objectWithoutProperties(_this$props2, _excluded);
      if (this.state.closed) {
        return null;
      }
      return /*#__PURE__*/React.createElement("div", _extends({
        className: classNames('ffe-system-message-wrapper', "ffe-system-message-wrapper--".concat(modifier), {
          'ffe-system-message-wrapper--coloredbg': onColoredBg
        }, className),
        role: "group",
        ref: function ref(_self) {
          _this3._self = _self;
        },
        style: {
          transition: "height ".concat(animationLengthMs / 1000, "s")
        }
      }, rest), /*#__PURE__*/React.createElement("div", {
        className: "ffe-system-message"
      }, /*#__PURE__*/React.createElement("span", {
        className: "ffe-system-message__icon"
      }, icon && /*#__PURE__*/React.cloneElement(icon, _objectSpread({}, icon.props))), /*#__PURE__*/React.createElement("p", {
        className: "ffe-system-message__content"
      }, children), /*#__PURE__*/React.createElement("button", {
        "aria-label": texts[locale].close,
        className: "ffe-system-message__close",
        onClick: this.close,
        type: "button"
      }, /*#__PURE__*/React.createElement(Icon, {
        fileUrl: "data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIGhlaWdodD0iMjAiIHZpZXdCb3g9IjAgLTk2MCA5NjAgOTYwIiB3aWR0aD0iMjAiPjxwYXRoIGQ9Ik00ODAtNDQyLjg0NyAzMDkuMDc2LTI3MS45MjRxLTguMzA3IDguMzA4LTE3Ljg4NCA4LTkuNTc2LS4zMDctMTguMjY4LTktOC42OTMtOC42OTItOC42OTMtMTguNTc2dDguNjkzLTE4LjU3Nkw0NDIuODQ3LTQ4MCAyNzEuOTI0LTY1MC45MjRxLTguMzA4LTguMzA3LTgtMTguMzg0LjMwNy0xMC4wNzYgOS0xOC43NjggOC42OTItOC42OTMgMTguNTc2LTguNjkzdDE4LjU3NiA4LjY5M0w0ODAtNTE3LjE1M2wxNzAuOTI0LTE3MC45MjNxOC4zMDctOC4zMDggMTguMzg0LTguNSAxMC4wNzYtLjE5MyAxOC43NjggOC41IDguNjkzIDguNjkyIDguNjkzIDE4LjU3NnQtOC42OTMgMTguNTc2TDUxNy4xNTMtNDgwbDE3MC45MjMgMTcwLjkyNHE4LjMwOCA4LjMwNyA4LjUgMTcuODg0LjE5MyA5LjU3Ni04LjUgMTguMjY4LTguNjkyIDguNjkzLTE4LjU3NiA4LjY5M3QtMTguNTc2LTguNjkzTDQ4MC00NDIuODQ3WiIvPjwvc3ZnPg==",
        size: "sm"
      }))));
    }
  }]);
}(Component);
SystemMessage.defaultProps = {
  animationLengthMs: 300,
  locale: 'nb',
  onClose: function onClose(f) {
    return f;
  }
};
SystemMessage.propTypes = {
  animationLengthMs: number,
  /** The content of the system message */
  children: node.isRequired,
  /** Additional classes added to the surrounding div */
  className: string,
  /** Override the default icon - use with caution! */
  icon: node.isRequired,
  /** 'nb', 'nn', or 'en' */
  locale: oneOf(['en', 'nb', 'nn']),
  /**
   * The type of system message. Used internally only-
   * @ignore
   **/
  modifier: oneOf(['error', 'info', 'success', 'news']),
  /** Callback for when the system message has been closed (after animation ends) */
  onClose: func,
  /* Adds alternative styling for better contrast on certain backgrounds */
  onColoredBg: bool
};
export default SystemMessage;
